/*
******************************************************************************
**  IO Interface to the Typhoon System
**
**
**  --------------------------------------------------------------------------
**  Copyright (C)  ReitzeTechnologies
**                 Elfenweg 10             eMail  Info@Reitze-Technologies.de
**                 D-76199 Karlsruhe
**                 Germany
******************************************************************************
*/


#ifndef _IO_CM2TYPHOON_H__
#define _IO_CM2TYPHOON_H__

#ifdef __cplusplus
extern "C" {
#endif

struct tInfos;

enum {
    CM2Ty_MotorsUsed = 2
};


    
/*** Input Vector, signals from hardware, ... */
/* - "in"/"out" from CMs point of view
**
*/
typedef struct tIO_CM2Ty {
    struct tIO_CM2Ty_Com {
	/* in */
	unsigned char	TyActive;	/* 0=Trq is not valid
					* 1=Trq can be used by CM
					*/
	
	/* out */
	unsigned char TyRqst;	/* 0=typhoon not requested
					* 1=typhoon is requested by CM, 
					*   Typhoon give me TyActive=1
					*/
	unsigned char TyParamRqst; 				
    } Com;
    
    
    /* out */
    struct tIO_CM2Ty_VhclCtrl {
	int   Key;	/* VehicleControl.Key, respect meaning of values!!! */
	float Gas;	/* VehicleControl.Gas */
	float Brake; 	/* VehicleControl.Brake */
	
	float Load;	/*@@@ */
    } VhclCtrl;

    
    struct tIO_CM2Ty_Motor {
	unsigned char	Active;		// 1=used by CM
	
	/* in / typhoon to CM */
	float Trq;

	/* out / CM to typhoon */
	float Load;		/* -1..0..+1 @@@ */
	float Spd;	   	// Data Misc file add parameters

	/* motor parameters */
	struct tIO_CM2Ty_Motor_Param {	/*@@@ XXX here add motor parameters
					 * needed by the MotorIF ans requested by Typhoon
					 */ 
	    /* cycleNo (time of request and transmission)*/
	    /*@@@ request parameters in Motor_New(),
	     * wait until Receive_cn is updated/newer than Rqst_cn
	     */
	    unsigned Rqst_cn;		
	    unsigned Receive_cn;
	} Param;
    } Motor[2];

} tIO_CM2Ty;

extern tIO_CM2Ty IO_CM2Ty;


extern unsigned int IO_CM2Ty_MIO;
extern unsigned int IO_CM2Ty_PCAN;

    

int	IO_CM2Ty_Init_First (void);
int	IO_CM2Ty_Init (void);
int	IO_CM2Ty_Init_Finalize (void);

int	IO_CM2Ty_Param_Get (struct tInfos *inf);
void	IO_CM2Ty_In  (unsigned CycleNo);
void	IO_CM2Ty_Out (unsigned CycleNo);

void	IO_CM2Ty_Cleanup (void);

/* implemented in TyMotor0.c, TyMotor1.c */
int 	Motor_Register_TyMotor0 (void);
int 	Motor_Register_TyMotor1 (void);

    
#ifdef __cplusplus
}
#endif

#endif	/* #ifndef _IO_CM2TYPHOON_H__ */
